==> ci_cmg_mb_cruise_migration-1.16-py3-none-any.whl: mb_cruise_migration/framework/consts/instrument_consts.py <==
class InstrumentConsts(object):
    BSSS = "BSSS"
    RESONSEABAT9003 = "RESONSEABAT9003"
    KONGSBERGEM710 = "KONGSBERGEM710"
    KONGSBERGEM122 = "KONGSBERGEM122"
    KONGSBERGEM302 = "KONGSBERGEM302"
    RESON8101 = "RESON8101"
    RESONSEABATT50P = "RESONSEABATT50P"
    SEABEAM = "SEABEAM"
    SIMRADEM300 = "SIMRADEM300"
    SIMRADEM300D = "SIMRADEM300D"
    SEABEAM1050D = "SEABEAM1050D"
    SIMRADEM120 = "SIMRADEM120"
    SEABEAM1180 = "SEABEAM1180"
    SEAMARCII = "SEAMARCII"
    ODOMECHOTRACCV2SINGLEBEAM = "ODOMECHOTRACCV2SINGLEBEAM"
    SIMRADEM950 = "SIMRADEM950"
    SEABEAM3012 = "SEABEAM3012"
    RESON7125 = "RESON7125"
    KONGSBERGEM712 = "KONGSBERGEM712"
    KONGSBERGEM3002 = "KONGSBERGEM3002"
    RESONSEABAT7160 = "RESONSEABAT7160"
    SIMRADEM3000 = "SIMRADEM3000"
    SIMRADEM1002 = "SIMRADEM1002"
    ELAC = "ELAC"
    KONGSBERGEM300 = "KONGSBERGEM300"
    KONGSBERGEM2040D = "KONGSBERGEM2040D"
    SEABEAM2000 = "SEABEAM2000"
    SIMRADEM302 = "SIMRADEM302"
    SIMRADEM1000 = "SIMRADEM1000"
    SIMRADEM3002D = "SIMRADEM3002D"
    SEABEAM1050 = "SEABEAM1050"
    SEASWATHPLUS = "SEASWATHPLUS"
    KONGSBERGEM124 = "KONGSBERGEM124"
    SIMRADME70 = "SIMRADME70"
    HOLLMINGECHOS625 = "HOLLMINGECHOS625"
    ATLASHYDROSWEEPDS = "ATLASHYDROSWEEPDS"
    RESONSEABAT9001 = "RESONSEABAT9001"
    SEABEAM2100 = "SEABEAM2100"
    RESONSEABAT8150 = "RESONSEABAT8150"
    MR1 = "MR1"
    KONGSBERGEM2040 = "KONGSBERGEM2040"
    KONGSBERGEM2040P = "KONGSBERGEM2040P"
    RESONSEABAT7101 = "RESONSEABAT7101"
    RESONSEABATT20P = "RESONSEABATT20P"
    KONGSBERGEM120 = "KONGSBERGEM120"
    R2SONIC2024 = "R2SONIC2024"
    KONGSBERGEM304 = "KONGSBERGEM304"
    SEABEAM2112 = "SEABEAM2112"
    ATLASHYDROSWEEPDS2 = "ATLASHYDROSWEEPDS2"
    RESONSEABAT8125 = "RESONSEABAT8125"
    RESONSEABAT8160 = "RESONSEABAT8160"
    RESONSEABAT8101 = "RESONSEABAT8101"
    UNKNOWN = "UNKNOWN"
    INNERSPACE455SINGLEBEAM = "INNERSPACE455SINGLEBEAM"
    LADSMKII = "LADSMKII"
    SIMRADEM121 = "SIMRADEM121"
    KONGSBERGEM1002 = "KONGSBERGEM1002"
    R2SONIC2022 = "R2SONIC2022"
    ELACNAUTIK3020 = "ELACNAUTIK3020"
    SEABEAM3012L3 = "SEABEAM3012L3"
    HYDROCHARTII = "HYDROCHARTII"
    SIMRADEM122 = "SIMRADEM122"
    SIMRADEM3002 = "SIMRADEM3002"
    HAWKEYEII = "HAWKEYEII"
    SEABEAM3012P1 = "SEABEAM3012P1"
    RESON7111 = "RESON7111"
    SEABEAM2120 = "SEABEAM2120"

==> ci_cmg_mb_cruise_migration-1.27-py3-none-any.whl: mb_cruise_migration/framework/consts/instrument_consts.py <==
class InstrumentConsts(object):
    BSSS = "BSSS"
    RESONSEABAT9003 = "RESONSEABAT9003"
    KONGSBERGEM710 = "KONGSBERGEM710"
    KONGSBERGEM122 = "KONGSBERGEM122"
    KONGSBERGEM302 = "KONGSBERGEM302"
    RESON8101 = "RESON8101"
    RESONSEABATT50P = "RESONSEABATT50P"
    SEABEAM = "SEABEAM"
    SIMRADEM300 = "SIMRADEM300"
    SIMRADEM300D = "SIMRADEM300D"
    SEABEAM1050D = "SEABEAM1050D"
    SIMRADEM120 = "SIMRADEM120"
    SEABEAM1180 = "SEABEAM1180"
    SEAMARCII = "SEAMARCII"
    ODOMECHOTRACCV2SINGLEBEAM = "ODOMECHOTRACCV2SINGLEBEAM"
    SIMRADEM950 = "SIMRADEM950"
    SEABEAM3012 = "SEABEAM3012"
    RESON7125 = "RESON7125"
    KONGSBERGEM712 = "KONGSBERGEM712"
    KONGSBERGEM3002 = "KONGSBERGEM3002"
    RESONSEABAT7160 = "RESONSEABAT7160"
    SIMRADEM3000 = "SIMRADEM3000"
    SIMRADEM1002 = "SIMRADEM1002"
    ELAC = "ELAC"
    KONGSBERGEM300 = "KONGSBERGEM300"
    KONGSBERGEM2040D = "KONGSBERGEM2040D"
    SEABEAM2000 = "SEABEAM2000"
    SIMRADEM302 = "SIMRADEM302"
    SIMRADEM1000 = "SIMRADEM1000"
    SIMRADEM3002D = "SIMRADEM3002D"
    SEABEAM1050 = "SEABEAM1050"
    SEASWATHPLUS = "SEASWATHPLUS"
    KONGSBERGEM124 = "KONGSBERGEM124"
    SIMRADME70 = "SIMRADME70"
    HOLLMINGECHOS625 = "HOLLMINGECHOS625"
    ATLASHYDROSWEEPDS = "ATLASHYDROSWEEPDS"
    RESONSEABAT9001 = "RESONSEABAT9001"
    SEABEAM2100 = "SEABEAM2100"
    RESONSEABAT8150 = "RESONSEABAT8150"
    MR1 = "MR1"
    KONGSBERGEM2040 = "KONGSBERGEM2040"
    KONGSBERGEM2040P = "KONGSBERGEM2040P"
    RESONSEABAT7101 = "RESONSEABAT7101"
    RESONSEABATT20P = "RESONSEABATT20P"
    KONGSBERGEM120 = "KONGSBERGEM120"
    R2SONIC2024 = "R2SONIC2024"
    KONGSBERGEM304 = "KONGSBERGEM304"
    SEABEAM2112 = "SEABEAM2112"
    ATLASHYDROSWEEPDS2 = "ATLASHYDROSWEEPDS2"
    RESONSEABAT8125 = "RESONSEABAT8125"
    RESONSEABAT8160 = "RESONSEABAT8160"
    RESONSEABAT8101 = "RESONSEABAT8101"
    UNKNOWN = "UNKNOWN"
    INNERSPACE455SINGLEBEAM = "INNERSPACE455SINGLEBEAM"
    LADSMKII = "LADSMkII"
    SIMRADEM121 = "SIMRADEM121"
    KONGSBERGEM1002 = "KONGSBERGEM1002"
    R2SONIC2022 = "R2SONIC2022"
    ELACNAUTIK3020 = "ELACNAUTIK3020"
    SEABEAM3012L3 = "SEABEAM3012L3"
    HYDROCHARTII = "HYDROCHARTII"
    SIMRADEM122 = "SIMRADEM122"
    SIMRADEM3002 = "SIMRADEM3002"
    HAWKEYEII = "HAWKEYEII"
    SEABEAM3012P1 = "SEABEAM3012P1"
    RESON7111 = "RESON7111"
    SEABEAM2120 = "SEABEAM2120"
